TBX — Translate Toolkit 2.0.0b4 documentation

# TBX

TBX is the LISA OSCAR standard for terminology and term exchange.

For information on more file formats, see Standards conformance.

## References

- Standard home page
- Specification
- ISO 30042 – TBX is an approved ISO standard
- Additional TBX resources

You might also be interested in reading about TBX-Basic – a simpler, reduced version of TBX with most of the useful features included.

Additionally notes and examples about TBX are available in Terminator TBX conformance notes which might help understanding this format.

Also you might want to use TBXChecker in order to check that TBX files are valid. Check the TBXChecker explanation.

## Conformance

Translate Toolkit TBX format support allows:

- Basic TBX file creation
- Creating a bilingual TBX from CSV using csv2tbx
- Using `<tig>` tags only
- Simple extraction of Parts of Speech and definitions

## Non-Conformance

The following are not yet supported:

- `id` attribute for `<termEntry>` tags
- Multiple languages
- Multiple translations in the same language
- Cross references
- Context
- Abbreviations
- Synonyms
- `<ntig>` tag, read and write

Other features can be picked from the Terminator TBX conformance notes which also include examples and notes about the TBX format.